NestedBlockDef class final
One nested block ("schema_settings { ... }") attached to a parent block.
Constructors
- NestedBlockDef({required String name, required NestingMode nesting, required BlockDef block, required Constraints constraints, int? minItems, int? maxItems, String? description})
-
const
Properties
- block → BlockDef
-
final
- constraints → Constraints
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxItems → int?
-
final
- minItems → int?
-
final
- name → String
-
final
- nesting → NestingMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited