ProviderSchemaIR class final
Top-level IR root: one provider's schema in unified form.
Constructors
-
ProviderSchemaIR({required String providerName, required String providerSource, required String providerVersion, required Map<
String, ResourceDef> resources, required Map<String, ResourceDef> dataSources}) -
const
Properties
-
dataSources
→ Map<
String, ResourceDef> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerName → String
-
final
- providerSource → String
-
final
- providerVersion → String
-
final
-
resources
→ Map<
String, ResourceDef> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited